import SwiftUI
import UniformTypeIdentifiers

struct MyFileData: Codable {
    var fileName: String
    var intItem: Int
    var strItem: String
}

struct ContentView: View {
    @State var fname: String = ""
    @State var intVal: Int = 0
    @State var strVal: String = ""
    @State var readFile: Bool = false
    @State var status = ""
    
    var body: some View {
        VStack {
            Text("Create a file").font(.title).fontWeight(.bold)
            Form {
                Section(header: Text("File Creation")) {
                    TextField("Filename", text: $fname)
                        .autocapitalization(.none).disableAutocorrection(true)
                    Stepper("Integer value: \(intVal)", value: $intVal, in: 0...100)
                    TextField("String value", text: $strVal)
                        .autocapitalization(.none).disableAutocorrection(true)
                }
                Section(header: Text("Status")) {
                    Text(status).foregroundColor(.secondary)
                }
            }
            HStack {
                Button("Create") {
                    if !fname.hasSuffix(".json") { fname.append(".json") }
                    let f = MyFileData(fileName: fname, intItem: intVal, strItem: strVal)
                    if let docRoot = try? FileManager.default.url(for: .documentDirectory,
                                                                     in: .userDomainMask, appropriateFor: nil, create: true) {
                        if let d = try? JSONEncoder().encode(f) {
                            do {
                                try d.write(to: docRoot.appendingPathComponent(f.fileName))
                            } catch {status = "Something bad happened w/ \(f.fileName)"}
                            status = "Success creating \(f.fileName)"
                        }
                    }
                }.padding()
                Button("Read") { readFile = true }.padding()
            }
        }.fileImporter(isPresented: $readFile, allowedContentTypes: [UTType.json]) { res in
            status = "hello?"
            if let url = try? res.get() {
                if let data = try? Data(contentsOf: url) {
                    if let f = try? JSONDecoder().decode(MyFileData.self, from: data) {
                        fname = f.fileName
                        intVal = f.intItem
                        strVal = f.strItem
                    }
                }
            }
        }
    }
}
